@@ -3,6 +3,7 @@ __author__ = "Damon May"
 from typing import Dict
 import pandas as pd
 import time
+from datetime import timedelta
 import seaborn as sns
 import logging
 from matplotlib.colors import is_color_like
@@ -37,7 +38,7 @@ class DerbyGame:
                 self.team_color_1 = team_color_dict[self.team_1_name]
                 self.team_color_2 = team_color_dict[self.team_2_name]
             except Exception as e:
-                logger.warn("Failed to find teams in color definitions. Dummying.")
+                logger.warn("Failed to find teams in color definitions. Using default colors.")
                 self.team_color_1 = sns.color_palette()[0]
                 self.team_color_2 = sns.color_palette()[1]
 
@@ -95,26 +96,29 @@ class DerbyGame:
 
         game_duration_s = 0
         for period in sorted(list(set(self.pdf_jams_data.PeriodNumber))):
-            logger.debug("Extracting jam data for period {period}")
+            logger.debug(f"Extracting jam data for period {period}")
             pdf_per = self.pdf_jams_data[self.pdf_jams_data.PeriodNumber == period]
             period_duration_s = (max(pdf_per.jam_endtime_seconds) -
                                  min(pdf_per.jam_starttime_seconds))
+            logger.debug(f"Period {period} duration: {period_duration_s} seconds")
             game_duration_s += period_duration_s
+        logger.debug(f"Game duration: {game_duration_s} seconds")
     
-        logger.debug("Calculating final scores")
-        final_score_team_1 = max(self.pdf_jams_data.TotalScore_1)
-        final_score_team_2 = max(self.pdf_jams_data.TotalScore_2)
+        logger.debug("Calculating scores")
+        score_team_1 = max(self.pdf_jams_data.TotalScore_1)
+        score_team_2 = max(self.pdf_jams_data.TotalScore_2)
 
         # Per @erevrav, injuries accrue to jams, not teams, so the proper quantity
         # to represent at the game level is the number of jams that ended in injury.
         n_jams_with_injury = sum(self.pdf_jams_data.Injury_1 |
                                  self.pdf_jams_data.Injury_2)
         gross_summary_dict = {
+            "Game Status": self.game_data_dict["game_status"],
             "Periods": n_periods,
             "Jams": n_jams,
-            "Total Game Time (min:sec)": time.strftime('%M:%S', time.gmtime(game_duration_s)),
-            f"{self.team_1_name} Final Score": final_score_team_1,
-            f"{self.team_2_name} Final Score": final_score_team_2,
+            "Total Game Time": str(timedelta(seconds = game_duration_s)),
+            f"{self.team_1_name} Score": score_team_1,
+            f"{self.team_2_name} Score": score_team_2,
             "Injury Jams": n_jams_with_injury,
             "Scoreboard Version": self.game_data_dict["scoreboard_version"]
         }
