@@ -70,8 +70,8 @@ def json_to_game_dataframe(game_json: Dict[Any, Any]) -> pd.DataFrame:
 
         # In-process games have both "CurrentGame" fields and fields
         # annotated with a game identifier. Complete games don't have
-        # "CurrentGame" fields.
-        # I think the "CurrentGame" fields are junk. Get rid of them.
+        # "CurrentGame" fields. So, if we find a "CurrentGame" field,
+        # use those and strip out all the fields with a game identifier.
         logger.debug(f"Found version 5. Checking for in-progress game...")
         is_in_progress_game = False
         for key in game_dict:
@@ -79,18 +79,19 @@ def json_to_game_dataframe(game_json: Dict[Any, Any]) -> pd.DataFrame:
                is_in_progress_game = True
                break
         if is_in_progress_game:
-            logger.debug(f"Found in-progress game. Stripping rows. Before: {len(game_dict)} keys")
+            logger.debug(f"Found in-progress game. Stripping rows with 'Scoreboard.Game('. Before: {len(game_dict)} keys")
             game_dict_new = {
-                key: game_dict[key]
+                ".".join([chunk for chunk in key.split(".") if "CurrentGame" != chunk]):
+                game_dict[key]
+                for key in game_dict
+                if not key.startswith("Scoreboard.Game(")
+            }
+        else:
+            game_dict_new = {
+                ".".join([chunk for chunk in key.split(".") if not chunk.startswith("Game(")]):
+                game_dict[key]
                 for key in game_dict
-                if not key.split(".")[1] == "CurrentGame"
             }
-            logger.debug(f"After: {len(game_dict)} keys.")
-        game_dict_new = {
-            ".".join([chunk for chunk in key.split(".") if not chunk.startswith("Game(")]):
-            game_dict[key]
-            for key in game_dict
-        }
         game_dict = game_dict_new
         
 
@@ -164,19 +165,36 @@ def extract_game_data_dict(pdf_game_state: pd.DataFrame) -> Dict[str, Any]:
     Returns:
         Dict[str, Any]: key-value pairs of game-level info
     """
-    team1_key = "ScoreBoard.Team(1).Name"
-    team2_key = "ScoreBoard.Team(2).Name"
+    try:
+        game_status = pdf_game_state[pdf_game_state.key == "ScoreBoard.State"].value.iloc[0]
+    except Exception as e:
+        logger.warn(f"Failed to extract game status. Exception: {e}")
+        game_status = "Unknown"
 
     team_name_1 = list(pdf_game_state[
-        pdf_game_state.key == team1_key].value)[0]
+        pdf_game_state.key == "ScoreBoard.Team(1).Name"].value)[0]
     team_name_2 = list(pdf_game_state[
-        pdf_game_state.key == team2_key].value)[0]
+        pdf_game_state.key == "ScoreBoard.Team(2).Name"].value)[0]
+
+    # Address an issue where both teams can have the same Name but different FullName
+    if team_name_1 == team_name_2:
+        logger.info("Teams have the same name. Using FullName instead.")
+        try:
+            team_name_1 = list(pdf_game_state[
+                pdf_game_state.key == "ScoreBoard.Team(1).FullName"].value)[0]
+            team_name_2 = list(pdf_game_state[
+                pdf_game_state.key == "ScoreBoard.Team(2).FullName"].value)[0]
+        except Exception as e:
+            logger.error("Could not find FullName for both teams. Using Name instead but adding a suffix to differentiate.")
+            team_name_1 = team_name_1 + " (1)"
+            team_name_2 = team_name_2 + " (1)"
 
     # Get rid of weird characters in team names
     team_name_1 = cleanup_team_name(team_name_1)
     team_name_2 = cleanup_team_name(team_name_2)
 
     return {
+        "game_status": game_status,
         "team_1": team_name_1,
         "team_2": team_name_2
     }
