@@ -6,6 +6,8 @@ from jamstats.plots.plot_util import prepare_to_plot
 from jamstats.util.resources import (
     get_jamstats_logo_image, get_jamstats_version
 )
+import inspect
+
 
 from jamstats.plots.jamplots import (
         plot_game_summary_table,
@@ -29,6 +31,7 @@ import matplotlib
 from datetime import datetime
 import io
 import logging
+import socket
 
 
 MIN_REQUERY_SERVER_SECONDS = 30
@@ -54,15 +57,34 @@ PLOT_NAME_FUNC_MAP = {
     "Team 2 Skaters": plot_skater_stats_team2,
 }
 
-def start(port: int, debug: bool = True, scoreboard_server: str = None,
-          scoreboard_port: int = None) -> None:
+def start(port: int, jamstats_ip: str = None, debug: bool = True, scoreboard_server: str = None,
+          scoreboard_port: int = None, anonymize_names=False,
+          theme="white") -> None:
+    """
+
+    Args:
+        port (int): port to start the jamstats server on
+        jamstats_ip (str, optional): IP address to start on. Defaults to None. If None, will infer
+        debug (bool, optional): _description_. Defaults to True.
+        scoreboard_server (str, optional): _description_. Defaults to None.
+        scoreboard_port (int, optional): _description_. Defaults to None.
+        anonymize_names (bool, optional): _description_. Defaults to False.
+        theme (str, optional): _description_. Defaults to "white".
+    """
     matplotlib.use('Agg')
     app.plotname_image_map = {}
     app.plotname_time_map = {}
-    prepare_to_plot()
+    prepare_to_plot(theme=theme)
     app.scoreboard_server = scoreboard_server
     app.scoreboard_port = scoreboard_port
-    app.run(host="127.0.0.1", port=port, debug=debug)
+    if jamstats_ip:
+        app.ip = jamstats_ip
+    else:
+        app.ip = socket.gethostbyname(socket.gethostname())
+    app.port = port
+    app.anonymize_names=anonymize_names
+    print(f"Starting jamstats server at http://{app.ip}:{app.port}")
+    app.run(host=app.ip, port=port, debug=debug)
 
 
 def set_game(derby_game: DerbyGame):
@@ -77,7 +99,7 @@ def index():
         seconds_since_update = (datetime.now() - app.game_update_time).total_seconds()
         if  seconds_since_update >= MIN_REQUERY_SERVER_SECONDS:
             logger.debug(f"Connecting to server {app.scoreboard_server}, "
-                         "port {app.scoreboard_port}...")
+                         f"port {app.scoreboard_port}...")
             try:
                 derby_game = load_inprogress_game_from_server(
                     app.scoreboard_server, app.scoreboard_port)
@@ -119,6 +141,12 @@ def index():
                                     <p>{plot_link_html}</p>
                                 </th>
                             </tr>
+                            <tr>
+                                <th align="left" valign="top" bgcolor="gray" width="200">
+                                    <p>jamstats server:port :</p>
+                                    <p>{app.ip}:{app.port}</p>
+                                </th>
+                            </tr>
                         </table>
                     </th>
                     <th>
@@ -159,7 +187,17 @@ def plot_figure(plot_name: str):
             should_rebuild = False
     if should_rebuild: 
         logger.debug(f"Rebuilding {plot_name}")
-        f = PLOT_NAME_FUNC_MAP[plot_name](app.derby_game)
+
+        plotfunc = PLOT_NAME_FUNC_MAP[plot_name]
+
+        # add anonymize arg if the function has it
+        kwargs = {}
+        sig = inspect.signature(plotfunc)
+        if "anonymize_names" in sig.parameters:
+            kwargs["anonymize_names"] = app.anonymize_names
+
+        f = plotfunc(app.derby_game, **kwargs)
+
         app.plotname_image_map[plot_name] = f
         app.plotname_time_map[plot_name] = datetime.now() 
     f = app.plotname_image_map[plot_name]
